@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # coding: UTF-8
 # Rec10 TS Recording Tools
-# Copyright (C) 2009-2010 Yukikaze
+# Copyright (C) 2009-2011 Yukikaze
 import os
 import os.path
 import time
@@ -13,10 +13,10 @@ import configreader
 import chdb
 import tv2mp4
 import tv2ts
-def test_all_ch_encode(option,stime):
-    chl=chdb.getall()
+def testAllCHEncode(option,stime):
+    chl=chdb.getAllCH()
     print chl
-    path= configreader.getpath("test")
+    path= configreader.getConfPath("test")
     tpath=os.path.join(path, "encode_test")
     if not os.path.exists(tpath):
         os.mkdir(tpath)
@@ -40,4 +40,4 @@ if __name__ == "__main__":
     (opts,args)=parser.parse_args(sys.argv)
     if opts.encode_option != "":##-sの場合
         print "test_all_ch_encode"
-        test_all_ch_encode(opts.encode_option, "10")
\ No newline at end of file
+        testAllCHEncode(opts.encode_option, "10")
