@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # coding: UTF-8
 # Rec10 TS Recording Tools
-# Copyright (C) 2009-2010 Yukikaze
+# Copyright (C) 2009-2011 Yukikaze
 import ConfigParser
 import os
 import os.path
@@ -10,25 +10,19 @@ confp = ConfigParser.SafeConfigParser()
 Conf = 'rec10.conf'
 confpath=os.path.join(mypath,Conf)
 confp.read(confpath)
-def getpath(string):
+def getTempConfPath(string):
     global confp
     return confp.get('path', string)
-def getdbpath(string):
-    global confp
-    return confp.get('db', string)
-def getenv(string):
-    global confp
-    return confp.get('env', string)
-def setpath(option,value):
+def setTempConfPath(option,value):
     global confp
     return confp.set('path',option,value)
-def setdbpath(option,value):
+def setTempConfDB(option,value):
     global confp
     return confp.set('db',option,value)
-def setenv(option,value):
+def setTempConfEnv(option,value):
     global confp
     return confp.set('env',option,value)
-def writeconf():
+def writeTempConf():
     global confp
     f=open(confpath,"w")
     confp.write(f)
