@@ -1,5 +1,5 @@
-#!/bin/sh
+#!/bin/bash
 SELF_DIR=`dirname $0`
 cd ${SELF_DIR}
-export LANG="ja_JP.UTF-8" && python2.6 ./install.py
+export LANG="ja_JP.UTF-8" && python ./install.py
 mv Makefile.base Makefile
