@@ -1,12 +1,12 @@
+import tv2ts
 #!/usr/bin/python
 # coding: UTF-8
 # Rec10 TS Recording Tools
-# Copyright (C) 2009-2010 Yukikaze
+# Copyright (C) 2009-2011 Yukikaze
 #import sys
 import epgdb
 import os
 import time
-from ts2x264 import ts2x264
 import tv2avi
 import tv2mkv
 import checker
@@ -38,9 +38,10 @@ import rec10d
 import datetime
 import tv2mp4
 import ts2x264
+import recque
 path = str(os.path.dirname(os.path.abspath(__file__))) + "/"
 recpath = "/home/ftpusr/ftp-tmp/Recording/"
 ftpusr = "/home/ftpusr/ftp-tmp"
 recordedpath = u"/home/ftpusr/ftp-video"
 if __name__ == "__main__":
-    print ts2x264.get_x264core_version()
\ No newline at end of file
+    ""
\ No newline at end of file
