@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # coding: UTF-8
 # Rec10 TS Recording Tools
-# Copyright (C) 2009-2010 Yukikaze
+# Copyright (C) 2009-2011 Yukikaze
 import commands
 import configreader
 import os
@@ -10,6 +10,7 @@ import re
 import random
 import time
 import traceback
+import zip
 
 import recdblist
 def ts2x264(pin, pout, opts):#sizeは"HD"か"SD"
@@ -21,8 +22,8 @@ def ts2x264(pin, pout, opts):#sizeは"HD"か"SD"
     size="HD"
     crf=18
     quality=4
-    quality=int(configreader.getenv("x264_preset"))
-    crf=int(configreader.getenv("crf"))
+    quality=int(configreader.getConfEnv("x264_preset"))
+    crf=int(configreader.getConfEnv("crf"))
     deinterlace=1
     if re.search("H", opts):
         size = "HD"
@@ -32,18 +33,18 @@ def ts2x264(pin, pout, opts):#sizeは"HD"か"SD"
         size = "FullHD"
     if re.search("W",opts):
         size = "WVGA"
-    if re.search("MW8", opts):
+    if re.search("MW1",opts):
         size = "QVGA_BASE"
         crf=crf+4
-    if re.search("MW9", opts):
+    if re.search("MW2", opts):
         size = "WVGA_BASE"
         crf=crf+2
     if re.search("v", opts):
         is24fps=1
-        crf=int(configreader.getenv("animation_crf"))
+        crf=int(configreader.getConfEnv("animation_crf"))
     if re.search("a", opts):
         is24fps=1
-        crf=int(configreader.getenv("animation_crf"))
+        crf=int(configreader.getConfEnv("animation_crf"))
     if re.search("I", opts):
         deinterlace=0
     if re.search("q",opts):
@@ -62,23 +63,19 @@ def ts2x264(pin, pout, opts):#sizeは"HD"か"SD"
         crf=crf-1
     if re.search("p",opts):
         crf=crf-2
-    if re.search("d",opts):
-        encode_ffmpeg_sar(pin,pout,size,is24fps,quality,crf,deinterlace)
-    elif re.search("5",opts):
-        encode_ffmpeg_sar(pin,pout,size,is24fps,quality,crf,deinterlace)
-    elif re.search("b",opts):
-        try:
-            tm2v=pin.replace(".ts",".m2v")
-            encode_sar(tm2v, pout,size,is24fps,quality,crf,deinterlace)
-        except Exception, inst:
-            recdblist.Commonlogex("Error", "ts2x264(ts2x264.py)", str(type(inst)), str(inst)+traceback.format_exc(),log_level=200)
+    if re.search("d",opts):#二カ国語放送の場合
+        tm2v=pin.replace(".ts",".m2v")
+        encodeFfmpegSar(tm2v,pout,size,is24fps,quality,crf,deinterlace)
+    elif re.search("5",opts):#5.1chの場合
+        encodeFfmpegSar(pin,pout,size,is24fps,quality,crf,deinterlace)
     else:
         try:
-            encode_sar(pin, pout,size,is24fps,quality,crf,deinterlace)
+            encodeMencoderSar(pin, pout,size,is24fps,quality,crf,deinterlace)
         except Exception, inst:
-            recdblist.Commonlogex("Error", "ts2x264(ts2x264.py)", str(type(inst)), str(inst)+traceback.format_exc(),log_level=200)
-def encode_sar(pin,pout,size,is24fps,quality,crf,deinterlace=1):
-    mencoder=configreader.getpath("mencoder")
+            recdblist.addCommonlogEX("Error", "ts2x264(ts2x264.py)", str(type(inst)), str(inst)+traceback.format_exc(),log_level=200)
+def encodeMencoderSar(pin,pout,size,is24fps,quality,crf,deinterlace=1):
+    mencoder=configreader.getConfPath("mencoder")
+    tee=configreader.getConfPath("tee")
     encvf=""
     txt=""
     encvf="-sws 9 -vf yadif=0,pp=l5"
@@ -90,7 +87,7 @@ def encode_sar(pin,pout,size,is24fps,quality,crf,deinterlace=1):
     x264preset=""
     x264tune=""
     x264_bitrate="5000"
-    tsar=getMoviePAR(pin)
+    tsar=getMoviePAR2(pin)
     x264sar=str(tsar[0])+":"+str(tsar[1])
     if is24fps==1:
         ofps="-ofps 24000/1001"
@@ -100,37 +97,37 @@ def encode_sar(pin,pout,size,is24fps,quality,crf,deinterlace=1):
         encvf="-sws 9 -vf pullup,softskip"
         harddup=",pp=l5,unsharp=l3x3:0.75:c3x3:0.75,hqdn3d=2:1:2,harddup"
     if size == "HD":
-        tsize=get_par_size(pin,720)
+        tsize=getParSize(pin,720)
         encvf = encvf + ",scale=-3:720::0:3"+harddup
         x264streamsize=str(tsize[0])+u"x720"
         x264_bitrate="2500"
     elif size == "WVGA":
-        tsize=get_par_size(pin,480)
+        tsize=getParSize(pin,480)
         encvf = encvf + ",scale=-3:480::0:3"+harddup
         x264streamsize=str(tsize[0])+u"x480"
         x264_bitrate="1500"
     elif size == "FullHD":
-        tsize=get_par_size(pin,1080)
+        tsize=getParSize(pin,1080)
         encvf = encvf + ",scale=-3:1080::0:3"+harddup
         x264streamsize=str(tsize[0])+u"x1080"
         x264_bitrate="5000"
     elif size == "QVGA_BASE":
-        tsize=get_par_size(pin,240)
+        tsize=getParSize(pin,240)
         encvf = encvf + ",scale=-3:240::0:3"+harddup
         x264streamsize=str(tsize[0])+u"x240"
         x264_bitrate="300"
     elif size == "WVGA_BASE":
-        tsize=get_par_size(pin,480)
+        tsize=getParSize(pin,480)
         encvf = encvf + ",scale=-3:480::0:3"+harddup
         x264streamsize=str(tsize[0])+u"x480"
         x264_bitrate="1500"
     else:
-        tsize=get_par_size(pin,720)
+        tsize=getParSize(pin,720)
         encvf = encvf + ",scale=-3:720::0:3"+harddup
         x264streamsize=str(tsize[0])+u"x720"
         x264_bitrate="2500"
     if deinterlace==0:
-        tsize=getMovieBaseSize(pin)
+        tsize=getMovieBaseSize2(pin)
         ofps="-ofps 30000/1001"
         #fps="-fps 30000/1001"
         fps=""
@@ -162,10 +159,12 @@ def encode_sar(pin,pout,size,is24fps,quality,crf,deinterlace=1):
         x264preset=u"slow"
     elif quality==6:
         x264preset=u"slower"
+    else:
+        x264preset=u"medium"
     if size == "WVGA_BASE" or size == "QVGA_BASE":
         x264profile=" --level 32 --profile baseline "
     else:
-        x264profile=" --level 42 --profile high "
+        x264profile=" --level 41 --profile high "
     x264crf=str(crf)
     os.environ['LANG']="ja_JP.UTF-8"
     random.seed(pin)
@@ -174,26 +173,38 @@ def encode_sar(pin,pout,size,is24fps,quality,crf,deinterlace=1):
     temptime=temptime % 9697
     random.jumpahead(temptime)
     streampath=os.path.join(os.path.dirname(pin),str(random.randint(10000, 99999999)))
-    os.system(u"mkfifo "+streampath)
-    encexe=mencoder+u" \""+pin+u"\" -vfm ffmpeg -quiet "+encvf+u",format=i420 "+fps+" "+ofps+" -oac mp3lame -ovc raw -of rawvideo -o \""+streampath+"\" & "
-    encexe=encexe+get_x264_commandline(x264preset, x264sar, x264fps, x264profile, x264tune, pout, streampath, x264streamsize, crf=x264crf)
+    unicode(commands.getoutput(u"mkfifo "+streampath),'utf-8','ignore')
+    logmencoder=recdblist.getLogTitle(pin)+".mencoder.log"
+    logx264=recdblist.getLogTitle(pin)+".x264.log"
+    encexe=mencoder+u" \""+pin+u"\" -quiet -vfm ffmpeg "+encvf+u",format=i420 "+fps+" "+ofps+" -oac mp3lame -ovc raw -of rawvideo -o \""+streampath+"\" 2>&1 | "+tee+" \""+logmencoder+"\" & "
+    encexe=encexe+getX264Commandline(x264preset, x264sar, x264fps, x264profile, x264tune, pout, streampath, x264streamsize, crf=x264crf)
     #encexe=encexe+u" nice -n 19 "+x264+" "+x264_sar+" "+x264crf+u" "+x264_addline+u"  --threads "+x264_thread+" "+x264profile+x264preset+" "+x264tune+" "+x264fps+" -o \""+pout+"\" "+streampath+" "+x264streamsize
-    encexe=u"nice -n 19 " +encexe
+    encexe=u"nice -n 19 " +encexe+" 2>&1 | "+tee+" \""+logx264+"\""
+    try:
+        recdblist.addCommandSelfLog(pin, encexe)
+    except Exception, inst:
+        print type(inst)
+        print str(inst)
+        print traceback.print_exc(file=sys.stdout)
     recdblist.printutf8(encexe)
     txt=""
     try:
         txt=unicode(commands.getoutput(encexe.encode('utf-8')),'utf-8','ignore')
     except:
         ""
-    os.system("rm "+streampath)
+    os.remove(streampath)
+    zip.addFile2FileZip(logmencoder, recdblist.getLogTitle(pin)+".log.zip")
+    zip.addFile2FileZip(logx264, recdblist.getLogTitle(pin)+".log.zip")
+    os.remove(logmencoder)
+    os.remove(logx264)
     recdblist.addCommandLog(pin, u"Mencoder", encexe, txt)
-
-
-def encode_ffmpeg_sar(pin,pout,size,is24fps,quality,crf,deinterlace=1):
+#    recdblist.addCommandLogTar(pin,u"Mencoder","mencoder", encexe,txt)
+def encodeFfmpegSar(pin,pout,size,is24fps,quality,crf,deinterlace=1):
     """
 
     """
-    ffmpeg=configreader.getpath("ffmpeg")
+    ffmpeg=configreader.getConfPath("ffmpeg")
+    tee=configreader.getConfPath("tee")
     fps=u"-r 29.970030 "
     x264fps="30000/1001"
     x264streamsize=""
@@ -201,46 +212,46 @@ def encode_ffmpeg_sar(pin,pout,size,is24fps,quality,crf,deinterlace=1):
     x264tune=""
     x264_bitrate="2500"
     x264_thread="auto"
-    tsar=getMoviePAR(pin)
+    tsar=getMoviePAR2(pin)
     filter="-deinterlace"
     x264sar=str(tsar[0])+":"+str(tsar[1])
     if size == "HD":
-        tsize=get_par_size(pin,720)
+        tsize=getParSize(pin,720)
         s = "-s "+str(tsize[0])+"x720 "
         x264streamsize=str(tsize[0])+u"x720"
         x264_bitrate="2500"
     elif size == "WVGA":
-        tsize=get_par_size(pin,480)
+        tsize=getParSize(pin,480)
         s = "-s "+str(tsize[0])+"x480 "
         x264streamsize=str(tsize[0])+u"x480"
         x264_bitrate="1500"
     elif size == "FullHD":
-        tsize=get_par_size(pin,1080)
+        tsize=getParSize(pin,1080)
         s = "-s "+str(tsize[0])+"x1080 "
         x264streamsize=str(tsize[0])+u"x1080"
         x264_bitrate="5000"
     elif size == "SD":
-        tsize=get_par_size(pin,480)
+        tsize=getParSize(pin,480)
         s = "-s "+str(tsize[0])+"x480 "
         x264streamsize=str(tsize[0])+u"x480"
         x264_bitrate="1250"
     elif size == "QVGA_BASE":
-        tsize=get_par_size(pin,240)
+        tsize=getParSize(pin,240)
         s = "-s "+str(tsize[0])+"x240 "
         x264streamsize=str(tsize[0])+u"x240"
         x264_bitrate="300"
     elif size == "WVGA_BASE":
-        tsize=get_par_size(pin,480)
+        tsize=getParSize(pin,480)
         s = "-s "+str(tsize[0])+"x480 "
         x264streamsize=str(tsize[0])+u"x480"
         x264_bitrate="1500"
     else:
-        tsize=get_par_size(pin,720)
+        tsize=getParSize(pin,720)
         s = "-s "+str(tsize[0])+"x720 "
         x264streamsize=str(tsize[0])+u"x720"
         x264_bitrate="2500"
     if deinterlace==0:
-        tsize=getMovieBaseSize(pin)
+        tsize=getMovieBaseSize2(pin)
         fps=""
         s = "-s "+str(tsize[0])+"x"+str(tsize[1])+" "
         x264fps="30000/1001"
@@ -259,26 +270,36 @@ def encode_ffmpeg_sar(pin,pout,size,is24fps,quality,crf,deinterlace=1):
         x264preset=u"slow"
     elif quality==6:
         x264preset=u"slower"
+    else:
+        x264preset=u"medium"
     if size == "WVGA_BASE" or size == "QVGA_BASE":
         x264profile=" --level 32 --profile baseline "
     else:
-        x264profile=" --level 42 --profile high "
+        x264profile=" --level 41 --profile high "
     x264crf=str(crf)
     txt=""
     os.environ['LANG']="ja_JP.UTF-8"
-    exe=ffmpeg+u" -y -i \""+pin+"\" -vsync 400 -vcodec rawvideo -pix_fmt yuv420p "+s+fps+" "+filter+" -an -f rawvideo - | "
-    exe=exe+get_x264_commandline(x264preset, x264sar, x264fps, x264profile, x264tune, pout,"-", x264streamsize, crf=x264crf)
-    exe = "nice -n 19 " + exe
+    log_ffmpeg=recdblist.getLogTitle(pin)+".ffmpeg.log"
+    log_x264=recdblist.getLogTitle(pin)+".x264.log"
+    exe=ffmpeg+u" -y -i \""+pin+"\" -vsync 400 -vcodec rawvideo -pix_fmt yuv420p "+s+fps+" "+filter+" -an -f rawvideo - 2> \""+log_ffmpeg+"\" | "
+    exe=exe+getX264Commandline(x264preset, x264sar, x264fps, x264profile, x264tune, pout,"-", x264streamsize, crf=x264crf)
+    exe = "nice -n 19 " + exe+" 2>&1 | "+tee+" \""+log_x264+"\""
     txt=""
+    #recdblist.addCommandSelfLog(log_ffmpeg,recdblist.getLogTitle(pin)+".log.zip")
+    #recdblist.addCommandSelfLog(log_x264,recdblist.getLogTitle(pin)+".log.zip")
     recdblist.printutf8(exe)
+    recdblist.addCommandSelfLog(pin,exe)
     try:
         txt=unicode(commands.getoutput(exe.encode('utf-8')),'utf-8','ignore')
     except:
         ""
     recdblist.addCommandLog(pin, u"FFmpeg動画エンコード", exe, txt)
-
+    zip.addFile2FileZip(log_ffmpeg, recdblist.getLogTitle(pin+".log.zip"))
+    zip.addFile2FileZip(log_x264, recdblist.getLogTitle(pin+".log.zip"))
+    os.remove(log_ffmpeg)
+    os.remove(log_x264)
 def getMovieBaseSize(pin):
-    ffmpeg=configreader.getpath("ffmpeg")
+    ffmpeg=configreader.getConfPath("ffmpeg")
     os.environ['LANG']="ja_JP.UTF-8"
     exe=ffmpeg+u" -i \""+pin+"\" 2>&1"
     txts=unicode(commands.getoutput(exe.encode('utf-8')),'utf-8','ignore')
@@ -299,13 +320,35 @@ def getMovieBaseSize(pin):
                 sizeMaxX=tX
                 sizeMaxY=tY
     return [sizeMaxX,sizeMaxY]
+def getMovieBaseSize2(pin):##動画開始後すぐに解像度が変更されたときに対処
+    ffmpeg=configreader.getConfPath("ffmpeg")
+    os.environ['LANG']="ja_JP.UTF-8"
+    exe=ffmpeg+u" -ss 5 -fs 1 -i \""+pin+"\" \""+pin+".size.ts\" 2>&1"
+    txts=unicode(commands.getoutput(exe.encode('utf-8')),'utf-8','ignore')
+    rT=re.compile(u"Stream.*#.*:.*\D+([\d]+x[\d]+)\D+PAR\D+(\d+:\d+)\D+.*\Z")
+    sizeMaxX=0
+    sizeMaxY=0
+    txtls=txts.split("\n")
+    for t in txtls:
+        rM=rT.search(t)
+        if rM:
+            sizetxt=rM.group(1)
+            partxt=rM.group(2)
+            tX=int(sizetxt.split("x")[0])
+            tY=int(sizetxt.split("x")[1])
+            tEX=int(partxt.split(":")[0])
+            tEY=int(partxt.split(":")[1])
+            if sizeMaxX<tX:
+                sizeMaxX=tX
+                sizeMaxY=tY
+    os.remove(pin+".size.ts")
+    return [sizeMaxX,sizeMaxY]
 def getMoviePAR(pin):
-    ffmpeg=configreader.getpath("ffmpeg")
+    ffmpeg=configreader.getConfPath("ffmpeg")
     os.environ['LANG']="ja_JP.UTF-8"
     exe=ffmpeg+u" -i \""+pin+"\" 2>&1"
     txts=unicode(commands.getoutput(exe.encode('utf-8')),'utf-8','ignore')
     rT=re.compile(u".*Stream.*#.*:.*\D+([\d]+x[\d]+)\D+PAR\D+(\d+:\d+)\D+.*\Z")
-    #rT=re.compile(u".*Stream.*#.*:.*\D+([\d]+x[\d]+)\D+.*DAR\D+(\d+:\d+)\D+.*\Z")
     sizeMaxX=0
     parx=0
     pary=0
@@ -328,8 +371,37 @@ def getMoviePAR(pin):
                     parx=tEX
                     pary=tEY
     return [parx,pary]
+def getMoviePAR2(pin):
+    ffmpeg=configreader.getConfPath("ffmpeg")
+    os.environ['LANG']="ja_JP.UTF-8"
+    exe=ffmpeg+u" -ss 5 -fs 1 -i \""+pin+"\" \""+pin+".size.ts\" 2>&1"
+    txts=unicode(commands.getoutput(exe.encode('utf-8')),'utf-8','ignore')
+    rT=re.compile(u".*Stream.*#.*:.*\D+([\d]+x[\d]+)\D+PAR\D+(\d+:\d+)\D+.*\Z")
+    sizeMaxX=0
+    parx=0
+    pary=0
+    txtls=txts.split("\n")
+    for t in txtls:
+        rM=rT.match(t)
+        if rM:
+            sizetxt=rM.group(1)
+            dartxt=rM.group(2)
+            tX=int(sizetxt.split("x")[0])
+            tY=int(sizetxt.split("x")[1])
+            tEX=int(dartxt.split(":")[0])
+            tEY=int(dartxt.split(":")[1])
+            if sizeMaxX<tX:
+                sizeMaxX=tX
+                if tX==1920 and tY==1080:
+                    parx=1
+                    pary=1
+                else:
+                    parx=tEX
+                    pary=tEY
+    os.remove(pin+".size.ts")
+    return [parx,pary]
 def getMovieDAR(pin):
-    ffmpeg=configreader.getpath("ffmpeg")
+    ffmpeg=configreader.getConfPath("ffmpeg")
     os.environ['LANG']="ja_JP.UTF-8"
     exe=ffmpeg+u" -i \""+pin+"\" 2>&1"
     txts=unicode(commands.getoutput(exe.encode('utf-8')),'utf-8','ignore')
@@ -356,8 +428,37 @@ def getMovieDAR(pin):
                     darx=tEX
                     dary=tEY
     return [darx,dary]
-def get_par_size(pin,y):
-    tSize=getMovieBaseSize(pin)
+def getMovieDAR2(pin):
+    ffmpeg=configreader.getConfPath("ffmpeg")
+    os.environ['LANG']="ja_JP.UTF-8"
+    exe=ffmpeg+u" -ss 5 -fs 1 -i \""+pin+"\" \""+pin+".size.ts\" 2>&1"
+    txts=unicode(commands.getoutput(exe.encode('utf-8')),'utf-8','ignore')
+    rT=re.compile(u".*Stream.*#.*:.*\D+([\d]+x[\d]+)\D+.*DAR\D+(\d+:\d+)\D+.*\Z")
+    sizeMaxX=0
+    darx=0
+    dary=0
+    txtls=txts.split("\n")
+    for t in txtls:
+        rM=rT.match(t)
+        if rM:
+            sizetxt=rM.group(1)
+            dartxt=rM.group(2)
+            tX=int(sizetxt.split("x")[0])
+            tY=int(sizetxt.split("x")[1])
+            tEX=int(dartxt.split(":")[0])
+            tEY=int(dartxt.split(":")[1])
+            if sizeMaxX<tX:
+                sizeMaxX=tX
+                if tX==1920 and tY==1080:
+                    darx=16
+                    dary=9
+                else:
+                    darx=tEX
+                    dary=tEY
+    os.remove(pin+".size.ts")
+    return [darx,dary]
+def getParSize(pin,y):
+    tSize=getMovieBaseSize2(pin)
     if tSize[1] != 0 :
         tX=tSize[0]*10*y/tSize[1]
         tY=y
@@ -369,9 +470,8 @@ def get_par_size(pin,y):
         tX=-1
         tY=-1
     return [tX,tY]
-
-def get_x264core_version():
-    x264=configreader.getpath("x264")
+def getX264CoreVersion():
+    x264=configreader.getConfPath("x264")
     t1=commands.getoutput(x264+" --help|grep core")
     rT=re.compile(u"x264 core:(\d*)[\d]*.*\Z")
     rM=rT.match(t1)
@@ -379,29 +479,29 @@ def get_x264core_version():
     if rM:
         v=int(rM.group(1))
     return v
-def get_x264_commandline(preset,sar,fps,x264profile,x264tune,pout,pin,x264streamsize,crf=0,bitrate=0):
-    x264=configreader.getpath("x264")
+def getX264Commandline(preset,sar,fps,x264profile,x264tune,pout,pin,x264streamsize,crf=-1,bitrate=0):
+    x264=configreader.getConfPath("x264")
     os.environ['LANG']="ja_JP.UTF-8"
     x264_sar="--sar "+sar
     x264preset=u"--preset "+preset
     x264fps="--fps "+fps
-    if crf==0:
+    if crf==-1:
         x264bitrate=u"--bitrate "+str(bitrate)
     else:
         x264crf=u"--crf "+str(crf)
-    x264_addline=configreader.getenv("x264_addline")
+    x264_addline=configreader.getConfEnv("x264_addline")
     x264_thread="auto"
     try:
-        xtt=configreader.getenv("x264_thread")
+        xtt=configreader.getConfEnv("x264_thread")
         xtt=int(xtt)
         if xtt>0:
             x264_thread=str(xtt)
     except:
         x264_thread="auto"
-    x264_addline=configreader.getenv("x264_addline")
-    if get_x264core_version()>103:
+    x264_addline=configreader.getConfEnv("x264_addline")
+    if getX264CoreVersion()>103:
         x264res=u"--input-res "+x264streamsize
         exe=u"nice -n 19 "+x264+" "+x264_sar+" "+x264crf+u" "+x264_addline+u" --colormatrix bt709 --threads "+x264_thread+" "+x264profile+x264preset+" "+x264tune+" "+x264fps+" "+x264res+" -o \""+pout+"\" "+pin
     else:
         exe=u"nice -n 19 "+x264+" "+x264_sar+" "+x264crf+u" "+x264_addline+u" --colormatrix bt709 --threads "+x264_thread+" "+x264profile+x264preset+" "+x264tune+" "+x264fps+" -o \""+pout+"\" "+pin+" "+x264streamsize
-    return exe
\ No newline at end of file
+    return exe
