@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # coding: UTF-8
 # Rec10 TS Recording Tools
-# Copyright (C) 2009-2010 Yukikaze
+# Copyright (C) 2009-2011 Yukikaze
 
 import recdblist
 global z_ascii
@@ -10,8 +10,6 @@ global z_number
 global h_number
 z_ascii = u"ＡＢＣＤＥＦＧＨＩＪＫＬＭＮＯＰＱＲＳＴＵＶＷＸＹＺａｂｃｄｅｆｇｈｉｊｋｌｍｎｏｐｑｒｓｔｕｖｗｘｙｚ　！”＃＄％＆’（）＊＋，−．／：；＜＝＞？＠［￥］＾＿‘｛｜｝〜　〜"
 h_ascii = u"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz !\"#$%&'()*+,-./:;<=>?@[\]^_`{|}~ -"
-#z_ascii = z_ascii+Ur"\Ue28892\Uefbc8e"
-#h_ascii = h_ascii+Ur"\Uefbc8d."
 z_ascii_sp = unichr(0x2212)+unichr(0xff0e)
 h_ascii_sp = unichr(0x002d)+unichr(0x002e)
 z_number = u"０１２３４５６７８９"
@@ -46,17 +44,11 @@ def toHankaku_ABC123(str):
             s = h_number[i]
         retstr = retstr + s
     return retstr
-def check_Character_Type(character):
+def checkCharacterType(character):
     """
     return code is 1:Alphabet 2:Hiragana 3:Katakana 4:Kanji
     """
-    #recdblist.printutf8(character)
-    #recdblist.printutf8(type(character))
-    #character=character.encode('UTF-8')
-    #recdblist.printutf8(character)
-    #recdblist.printutf8(type(character))
     chcode=ord(character)
-    #recdblist.printutf8(ord(chcode))
     if chcode>=0x0000 and chcode<=0x007F:
         return 1
     elif chcode>=0x3040 and chcode<=0x309F:
